/*******************************************************************
 * Project: NGX-AUTO-DISABLE_FORMS                                 *
 * @file File: roles-and-permissions-related-content.directive.ts  *
 * @author Gökhan Sari - <g-sari@g-sari.com>                       *
 *******************************************************************/
import { Renderer2, ElementRef, AfterViewChecked, ViewContainerRef, OnInit } from '@angular/core';
/**
 * Checks roles and permissions of the current user and disables input fields on demand.
 * Note that you need to add the attribute 'rolesAndPermissionsRelatedContent' to the div container
 * i.e. ```<div rolesAndPermissionsRelatedContent></div>```, then depending on roles an permissions
 * the UI input fields inside the div will be disabled automatically. If needed you can also exclude
 * some input fields from being disabled by adding the css class 'exclude-from-roles-and-permissions'
 * i.e. ```<button class="exclude-from-roles-and-permissions"></button>```.
 */
export declare class RolesAndPermissionsRelatedContentDirective implements OnInit, AfterViewChecked {
    private renderer;
    private elementRef;
    private viewContainerRef;
    private currentRolesAndPermissionsBasedComponent;
    /**
     * @param renderer
     * @param elementRef
     * @param viewContainerRef
     */
    constructor(renderer: Renderer2, elementRef: ElementRef, viewContainerRef: ViewContainerRef);
    /**
     * Gets the current component.
     */
    ngOnInit(): void;
    /**
     * Checks roles and permissions and disable on demand.
     */
    ngAfterViewChecked(): void;
    /**
    * Checks roles and permissions of the current user and enables or disables the input fields inside of the marked div.
    */
    private checkRolesAndPermissionsAndEnableOrDisableInputs();
}
