import { Directive, Renderer2, ElementRef, ViewContainerRef } from '@angular/core';
/**
 * Checks roles and permissions of the current user and disables input fields on demand.
 * Note that you need to add the attribute 'rolesAndPermissionsRelatedContent' to the div container
 * i.e. ```<div rolesAndPermissionsRelatedContent></div>```, then depending on roles an permissions
 * the UI input fields inside the div will be disabled automatically. If needed you can also exclude
 * some input fields from being disabled by adding the css class 'exclude-from-roles-and-permissions'
 * i.e. ```<button class="exclude-from-roles-and-permissions"></button>```.
 */
var RolesAndPermissionsRelatedContentDirective = /** @class */ (function () {
    /**
     * @param renderer
     * @param elementRef
     * @param viewContainerRef
     */
    function RolesAndPermissionsRelatedContentDirective(renderer, elementRef, viewContainerRef) {
        this.renderer = renderer;
        this.elementRef = elementRef;
        this.viewContainerRef = viewContainerRef;
    }
    /**
     * Gets the current component.
     */
    /**
         * Gets the current component.
         */
    RolesAndPermissionsRelatedContentDirective.prototype.ngOnInit = /**
         * Gets the current component.
         */
    function () {
        this.currentRolesAndPermissionsBasedComponent = this.viewContainerRef._view.component;
    };
    /**
     * Checks roles and permissions and disable on demand.
     */
    /**
         * Checks roles and permissions and disable on demand.
         */
    RolesAndPermissionsRelatedContentDirective.prototype.ngAfterViewChecked = /**
         * Checks roles and permissions and disable on demand.
         */
    function () {
        this.checkRolesAndPermissionsAndEnableOrDisableInputs();
    };
    /**
    * Checks roles and permissions of the current user and enables or disables the input fields inside of the marked div.
    */
    /**
        * Checks roles and permissions of the current user and enables or disables the input fields inside of the marked div.
        */
    RolesAndPermissionsRelatedContentDirective.prototype.checkRolesAndPermissionsAndEnableOrDisableInputs = /**
        * Checks roles and permissions of the current user and enables or disables the input fields inside of the marked div.
        */
    function () {
        var inputsNodeList = this.elementRef.nativeElement.querySelectorAll('button:not(.exclude-from-roles-and-permissions), ' +
            'input:not(.exclude-from-roles-and-permissions), ' +
            'textarea:not(.exclude-from-roles-and-permissions), ' +
            'select:not(.exclude-from-roles-and-permissions), ' +
            'checkbox:not(.exclude-from-roles-and-permissions)');
        if (inputsNodeList != null) {
            for (var i = 0; i < inputsNodeList.length; i++) {
                var input = inputsNodeList[i];
                if (this.currentRolesAndPermissionsBasedComponent.isViewReadOnly()) {
                    this.renderer.setProperty(input, 'disabled', true);
                }
            }
        }
    };
    RolesAndPermissionsRelatedContentDirective.decorators = [
        { type: Directive, args: [{
                    selector: '[rolesAndPermissionsRelatedContent]'
                },] },
    ];
    /** @nocollapse */
    RolesAndPermissionsRelatedContentDirective.ctorParameters = function () { return [
        { type: Renderer2, },
        { type: ElementRef, },
        { type: ViewContainerRef, },
    ]; };
    return RolesAndPermissionsRelatedContentDirective;
}());
export { RolesAndPermissionsRelatedContentDirective };
//# sourceMappingURL=roles-and-permissions-related-content.directive.js.map